# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fworkspace.proto\x12\tworkspace\x1a\x0evalidate.proto\"\x93\x04\n\tWorkspace\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\t \x01(\tH\x08\x88\x01\x01\x12!\n\x14text_secondary_color\x18\n \x01(\tH\t\x88\x01\x01\x12\x18\n\x0bis_personal\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x17\n\ncreated_at\x18\x0c \x01(\tH\x0b\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_colorB\x0e\n\x0c_is_personalB\r\n\x0b_created_at\"\xd1\x03\n\x11WorkspaceCreation\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\x08 \x01(\tH\x07\x88\x01\x01\x12!\n\x14text_secondary_color\x18\t \x01(\tH\x08\x88\x01\x01\x12\x18\n\x0bis_personal\x18\n \x01(\x08H\t\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_colorB\x0e\n\x0c_is_personal\"\xa5\x03\n\x0fWorkspaceUpdate\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\t \x01(\tH\x07\x88\x01\x01\x12!\n\x14text_secondary_color\x18\n \x01(\tH\x08\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_color\"\xb8\x02\n\rWorkspaceUser\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12.\n\x04role\x18\x03 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x02\x88\x01\x01\x12\x35\n\x06status\x18\x04 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x03\x88\x01\x01\x12\x16\n\tcreate_at\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x16\n\tupdate_at\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x07\n\x05_roleB\t\n\x07_statusB\x0c\n\n_create_atB\x0c\n\n_update_at\"\x90\x01\n\x13WorkspaceUserUpdate\x12.\n\x04role\x18\x01 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x00\x88\x01\x01\x12\x35\n\x06status\x18\x02 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x01\x88\x01\x01\x42\x07\n\x05_roleB\t\n\x07_status\"\xb1\x01\n\x0fWorkspacePlugin\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12\x14\n\x07payload\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x16\n\tcreate_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x05\n\x03_idB\x0f\n\r_workspace_idB\n\n\x08_payloadB\x0c\n\n_create_at\"9\n\x15WorkspacePluginUpdate\x12\x14\n\x07payload\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_payload\"q\n\x16WorkspaceResponseError\x12,\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x19.workspace.WorkspaceErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message\"B\n\x14WorkspaceListRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\n\n\x08_user_id\"\x82\x01\n\x15WorkspaceListResponse\x12(\n\nworkspaces\x18\x01 \x03(\x0b\x32\x14.workspace.Workspace\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x88\x01\n\x16WorkspaceCreateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x34\n\tworkspace\x18\x02 \x01(\x0b\x32\x1c.workspace.WorkspaceCreationH\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0c\n\n_workspace\"\x96\x01\n\x17WorkspaceCreateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"w\n\x13WorkspaceGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\x93\x01\n\x14WorkspaceGetResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"\x90\x01\n\x16WorkspaceUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x32\n\tworkspace\x18\x02 \x01(\x0b\x32\x1a.workspace.WorkspaceUpdateH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_workspace\"\x96\x01\n\x17WorkspaceUpdateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"z\n\x16WorkspaceDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"Z\n\x17WorkspaceDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"P\n\x18WorkspaceUserListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x8f\x01\n\x19WorkspaceUserListResponse\x12\x31\n\x0fworkspace_users\x18\x01 \x03(\x0b\x32\x18.workspace.WorkspaceUser\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"{\n\x17WorkspaceUserGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\xa5\x01\n\x18WorkspaceUserGetResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"\xce\x01\n\x1aWorkspaceUserUpdateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12;\n\x0eworkspace_user\x18\x03 \x01(\x0b\x32\x1e.workspace.WorkspaceUserUpdateH\x02\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x11\n\x0f_workspace_user\"\xa8\x01\n\x1bWorkspaceUserUpdateResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"~\n\x1aWorkspaceUserDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"^\n\x1bWorkspaceUserDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"v\n\x1cWorkspacePluginCreateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x14\n\x07payload\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\n\n\x08_payload\"\xb0\x01\n\x1dWorkspacePluginCreateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x81\x01\n\x19WorkspacePluginGetRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"\xad\x01\n\x1aWorkspacePluginGetResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"R\n\x1aWorkspacePluginListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x95\x01\n\x1bWorkspacePluginListResponse\x12\x35\n\x11workspace_plugins\x18\x01 \x03(\x0b\x32\x1a.workspace.WorkspacePlugin\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xda\x01\n\x1cWorkspacePluginUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12?\n\x10workspace_plugin\x18\x03 \x01(\x0b\x32 .workspace.WorkspacePluginUpdateH\x02\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_idB\x13\n\x11_workspace_plugin\"\xb0\x01\n\x1dWorkspacePluginUpdateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x84\x01\n\x1cWorkspacePluginDeleteRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"`\n\x1dWorkspacePluginDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error*\x8b\x02\n\x0eWorkspaceError\x12\x16\n\x12WORKSPACE_NO_ERROR\x10\x00\x12\x17\n\x13WORKSPACE_NOT_FOUND\x10\x01\x12!\n\x1dWORKSPACE_USER_ALREADY_EXISTS\x10\x02\x12\x1c\n\x18WORKSPACE_USER_NOT_FOUND\x10\x03\x12!\n\x1dWORKSPACE_USER_ALREADY_ACTIVE\x10\x04\x12(\n$USER_ALREADY_HAVE_PERSONAL_WORKSPACE\x10\x05\x12\x1e\n\x1aWORKSPACE_PLUGIN_NOT_FOUND\x10\x06\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xe8\x07\x42\x32Z0github.com/jupyter-naas/naas-models/go/workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workspace_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/jupyter-naas/naas-models/go/workspace'
  _globals['_WORKSPACE'].fields_by_name['id']._loaded_options = None
  _globals['_WORKSPACE'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['role']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _globals['_WORKSPACEUSER'].fields_by_name['status']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['role']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['status']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _globals['_WORKSPACEPLUGIN'].fields_by_name['id']._loaded_options = None
  _globals['_WORKSPACEPLUGIN'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGIN'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGIN'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACELISTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACELISTREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACECREATEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACECREATEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINCREATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINCREATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEERROR']._serialized_start=6170
  _globals['_WORKSPACEERROR']._serialized_end=6437
  _globals['_WORKSPACE']._serialized_start=47
  _globals['_WORKSPACE']._serialized_end=578
  _globals['_WORKSPACECREATION']._serialized_start=581
  _globals['_WORKSPACECREATION']._serialized_end=1046
  _globals['_WORKSPACEUPDATE']._serialized_start=1049
  _globals['_WORKSPACEUPDATE']._serialized_end=1470
  _globals['_WORKSPACEUSER']._serialized_start=1473
  _globals['_WORKSPACEUSER']._serialized_end=1785
  _globals['_WORKSPACEUSERUPDATE']._serialized_start=1788
  _globals['_WORKSPACEUSERUPDATE']._serialized_end=1932
  _globals['_WORKSPACEPLUGIN']._serialized_start=1935
  _globals['_WORKSPACEPLUGIN']._serialized_end=2112
  _globals['_WORKSPACEPLUGINUPDATE']._serialized_start=2114
  _globals['_WORKSPACEPLUGINUPDATE']._serialized_end=2171
  _globals['_WORKSPACERESPONSEERROR']._serialized_start=2173
  _globals['_WORKSPACERESPONSEERROR']._serialized_end=2286
  _globals['_WORKSPACELISTREQUEST']._serialized_start=2288
  _globals['_WORKSPACELISTREQUEST']._serialized_end=2354
  _globals['_WORKSPACELISTRESPONSE']._serialized_start=2357
  _globals['_WORKSPACELISTRESPONSE']._serialized_end=2487
  _globals['_WORKSPACECREATEREQUEST']._serialized_start=2490
  _globals['_WORKSPACECREATEREQUEST']._serialized_end=2626
  _globals['_WORKSPACECREATERESPONSE']._serialized_start=2629
  _globals['_WORKSPACECREATERESPONSE']._serialized_end=2779
  _globals['_WORKSPACEGETREQUEST']._serialized_start=2781
  _globals['_WORKSPACEGETREQUEST']._serialized_end=2900
  _globals['_WORKSPACEGETRESPONSE']._serialized_start=2903
  _globals['_WORKSPACEGETRESPONSE']._serialized_end=3050
  _globals['_WORKSPACEUPDATEREQUEST']._serialized_start=3053
  _globals['_WORKSPACEUPDATEREQUEST']._serialized_end=3197
  _globals['_WORKSPACEUPDATERESPONSE']._serialized_start=3200
  _globals['_WORKSPACEUPDATERESPONSE']._serialized_end=3350
  _globals['_WORKSPACEDELETEREQUEST']._serialized_start=3352
  _globals['_WORKSPACEDELETEREQUEST']._serialized_end=3474
  _globals['_WORKSPACEDELETERESPONSE']._serialized_start=3476
  _globals['_WORKSPACEDELETERESPONSE']._serialized_end=3566
  _globals['_WORKSPACEUSERLISTREQUEST']._serialized_start=3568
  _globals['_WORKSPACEUSERLISTREQUEST']._serialized_end=3648
  _globals['_WORKSPACEUSERLISTRESPONSE']._serialized_start=3651
  _globals['_WORKSPACEUSERLISTRESPONSE']._serialized_end=3794
  _globals['_WORKSPACEUSERGETREQUEST']._serialized_start=3796
  _globals['_WORKSPACEUSERGETREQUEST']._serialized_end=3919
  _globals['_WORKSPACEUSERGETRESPONSE']._serialized_start=3922
  _globals['_WORKSPACEUSERGETRESPONSE']._serialized_end=4087
  _globals['_WORKSPACEUSERUPDATEREQUEST']._serialized_start=4090
  _globals['_WORKSPACEUSERUPDATEREQUEST']._serialized_end=4296
  _globals['_WORKSPACEUSERUPDATERESPONSE']._serialized_start=4299
  _globals['_WORKSPACEUSERUPDATERESPONSE']._serialized_end=4467
  _globals['_WORKSPACEUSERDELETEREQUEST']._serialized_start=4469
  _globals['_WORKSPACEUSERDELETEREQUEST']._serialized_end=4595
  _globals['_WORKSPACEUSERDELETERESPONSE']._serialized_start=4597
  _globals['_WORKSPACEUSERDELETERESPONSE']._serialized_end=4691
  _globals['_WORKSPACEPLUGINCREATEREQUEST']._serialized_start=4693
  _globals['_WORKSPACEPLUGINCREATEREQUEST']._serialized_end=4811
  _globals['_WORKSPACEPLUGINCREATERESPONSE']._serialized_start=4814
  _globals['_WORKSPACEPLUGINCREATERESPONSE']._serialized_end=4990
  _globals['_WORKSPACEPLUGINGETREQUEST']._serialized_start=4993
  _globals['_WORKSPACEPLUGINGETREQUEST']._serialized_end=5122
  _globals['_WORKSPACEPLUGINGETRESPONSE']._serialized_start=5125
  _globals['_WORKSPACEPLUGINGETRESPONSE']._serialized_end=5298
  _globals['_WORKSPACEPLUGINLISTREQUEST']._serialized_start=5300
  _globals['_WORKSPACEPLUGINLISTREQUEST']._serialized_end=5382
  _globals['_WORKSPACEPLUGINLISTRESPONSE']._serialized_start=5385
  _globals['_WORKSPACEPLUGINLISTRESPONSE']._serialized_end=5534
  _globals['_WORKSPACEPLUGINUPDATEREQUEST']._serialized_start=5537
  _globals['_WORKSPACEPLUGINUPDATEREQUEST']._serialized_end=5755
  _globals['_WORKSPACEPLUGINUPDATERESPONSE']._serialized_start=5758
  _globals['_WORKSPACEPLUGINUPDATERESPONSE']._serialized_end=5934
  _globals['_WORKSPACEPLUGINDELETEREQUEST']._serialized_start=5937
  _globals['_WORKSPACEPLUGINDELETEREQUEST']._serialized_end=6069
  _globals['_WORKSPACEPLUGINDELETERESPONSE']._serialized_start=6071
  _globals['_WORKSPACEPLUGINDELETERESPONSE']._serialized_end=6167
# @@protoc_insertion_point(module_scope)
