# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: registry.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eregistry.proto\x12\x08registry\x1a\x0evalidate.proto\"\x8f\x01\n\x08Registry\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03uri\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_nameB\n\n\x08_user_idB\x06\n\x04_uri\"]\n\x13RegistryCredentials\x12\x15\n\x08username\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_usernameB\x0b\n\t_password\"b\n\x17RegistryCreationRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"R\n\x18RegistryCreationResponse\x12)\n\x08registry\x18\x01 \x01(\x0b\x32\x12.registry.RegistryH\x00\x88\x01\x01\x42\x0b\n\t_registry\"\x84\x01\n\x1dRegistryCreationResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message\"e\n\x13RegistryListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\">\n\x14RegistryListResponse\x12&\n\nregistries\x18\x01 \x03(\x0b\x32\x12.registry.Registry\"]\n\x12RegistryGetRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"M\n\x13RegistryGetResponse\x12)\n\x08registry\x18\x01 \x01(\x0b\x32\x12.registry.RegistryH\x00\x88\x01\x01\x42\x0b\n\t_registry\"\x7f\n\x18RegistryGetResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message\"3\n\x15RegistryDeleteRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\x82\x01\n\x1bRegistryDeleteResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message\"e\n\x1aRegistryCredentialsRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"\xaf\x01\n\x1bRegistryCredentialsResponse\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x37\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x1d.registry.RegistryCredentialsH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_credentials\"\x87\x01\n RegistryCredentialsResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message*X\n\rRegistryError\x12\x1b\n\x17REGISTRY_ALREADY_EXISTS\x10\x00\x12\x16\n\x12REGISTRY_NOT_FOUND\x10\x01\x12\x12\n\x0eNOT_AUTHORIZED\x10\x02\x42\x31Z/github.com/jupyter-naas/naas-models/go/registryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'registry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/jupyter-naas/naas-models/go/registry'
  _globals['_REGISTRY'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTRY'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_REGISTRYCREATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTRYCREATIONREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_REGISTRYGETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTRYGETREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_REGISTRYCREDENTIALSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTRYCREDENTIALSREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_REGISTRYCREDENTIALSRESPONSE'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTRYCREDENTIALSRESPONSE'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_REGISTRYERROR']._serialized_start=1679
  _globals['_REGISTRYERROR']._serialized_end=1767
  _globals['_REGISTRY']._serialized_start=45
  _globals['_REGISTRY']._serialized_end=188
  _globals['_REGISTRYCREDENTIALS']._serialized_start=190
  _globals['_REGISTRYCREDENTIALS']._serialized_end=283
  _globals['_REGISTRYCREATIONREQUEST']._serialized_start=285
  _globals['_REGISTRYCREATIONREQUEST']._serialized_end=383
  _globals['_REGISTRYCREATIONRESPONSE']._serialized_start=385
  _globals['_REGISTRYCREATIONRESPONSE']._serialized_end=467
  _globals['_REGISTRYCREATIONRESPONSEERROR']._serialized_start=470
  _globals['_REGISTRYCREATIONRESPONSEERROR']._serialized_end=602
  _globals['_REGISTRYLISTREQUEST']._serialized_start=604
  _globals['_REGISTRYLISTREQUEST']._serialized_end=705
  _globals['_REGISTRYLISTRESPONSE']._serialized_start=707
  _globals['_REGISTRYLISTRESPONSE']._serialized_end=769
  _globals['_REGISTRYGETREQUEST']._serialized_start=771
  _globals['_REGISTRYGETREQUEST']._serialized_end=864
  _globals['_REGISTRYGETRESPONSE']._serialized_start=866
  _globals['_REGISTRYGETRESPONSE']._serialized_end=943
  _globals['_REGISTRYGETRESPONSEERROR']._serialized_start=945
  _globals['_REGISTRYGETRESPONSEERROR']._serialized_end=1072
  _globals['_REGISTRYDELETEREQUEST']._serialized_start=1074
  _globals['_REGISTRYDELETEREQUEST']._serialized_end=1125
  _globals['_REGISTRYDELETERESPONSEERROR']._serialized_start=1128
  _globals['_REGISTRYDELETERESPONSEERROR']._serialized_end=1258
  _globals['_REGISTRYCREDENTIALSREQUEST']._serialized_start=1260
  _globals['_REGISTRYCREDENTIALSREQUEST']._serialized_end=1361
  _globals['_REGISTRYCREDENTIALSRESPONSE']._serialized_start=1364
  _globals['_REGISTRYCREDENTIALSRESPONSE']._serialized_end=1539
  _globals['_REGISTRYCREDENTIALSRESPONSEERROR']._serialized_start=1542
  _globals['_REGISTRYCREDENTIALSRESPONSEERROR']._serialized_end=1677
# @@protoc_insertion_point(module_scope)
