# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: credit.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63redit.proto\x12\x06\x63redit\x1a\x0evalidate.proto\"\xcb\x04\n\x11\x43reditTransaction\x12\x15\n\x08scenario\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04user\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04plan\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04type\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0bmeta_1_desc\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x13\n\x06meta_1\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x18\n\x0bmeta_2_desc\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x13\n\x06meta_2\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x18\n\x0bmeta_3_desc\x18\t \x01(\tH\x08\x88\x01\x01\x12\x13\n\x06meta_3\x18\n \x01(\tH\t\x88\x01\x01\x12\x15\n\x08quantity\x18\x0b \x01(\x02H\n\x88\x01\x01\x12\x11\n\x04unit\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x17\n\nunit_price\x18\r \x01(\x02H\x0c\x88\x01\x01\x12\x13\n\x06\x63redit\x18\x0e \x01(\x02H\r\x88\x01\x01\x12\x1a\n\rcredit_dollar\x18\x0f \x01(\x02H\x0e\x88\x01\x01\x12\x19\n\x0c\x64\x61te_extract\x18\x10 \x01(\tH\x0f\x88\x01\x01\x42\x0b\n\t_scenarioB\x07\n\x05_userB\x07\n\x05_planB\x07\n\x05_typeB\x0e\n\x0c_meta_1_descB\t\n\x07_meta_1B\x0e\n\x0c_meta_2_descB\t\n\x07_meta_2B\x0e\n\x0c_meta_3_descB\t\n\x07_meta_3B\x0b\n\t_quantityB\x07\n\x05_unitB\r\n\x0b_unit_priceB\t\n\x07_creditB\x10\n\x0e_credit_dollarB\x0f\n\r_date_extract\"[\n\x07\x42\x61lance\x12\x14\n\x07\x62\x61lance\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x1b\n\x0e\x62\x61lance_dollar\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\n\n\x08_balanceB\x11\n\x0f_balance_dollarB/Z-github.com/jupyter-naas/naas-models/go/creditb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'credit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/jupyter-naas/naas-models/go/credit'
  _globals['_CREDITTRANSACTION']._serialized_start=41
  _globals['_CREDITTRANSACTION']._serialized_end=628
  _globals['_BALANCE']._serialized_start=630
  _globals['_BALANCE']._serialized_end=721
# @@protoc_insertion_point(module_scope)
